embassy-stm32

Crates

git

Versions

stm32h745xg-cm4

Flavors

OPAMP1

Struct OPAMP1 

pub struct OPAMP1 { /* private fields */ }
OPAMP1 peripheral

Implementations

Source

impl OPAMP1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.