embassy-stm32

Crates

git

Versions

stm32h745xg-cm4

Flavors

OPAMP2

Struct OPAMP2 

pub struct OPAMP2 { /* private fields */ }
OPAMP2 peripheral

Implementations

Source

impl OPAMP2

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.